-- Author      : Nogarder
-- Create Date : 2015/3/4 3:59:27
local Localization=RS.Localization
local Tooltips=Localization.Tooltips


--
local Refresh=function(editbox,libfunc,forcematch)
	if(not libfunc)then
		editbox:SetText(editbox.Value)
		return
	end
	editbox.SetByMenu=true
	local value=editbox.Value
	local unit=RS.CheckLib(value,libfunc)
	--preview
	if(unit)then
		--RS.SetTextFont(editbox,unit.Font,unit.FontProfileName)
		--RS.SetTexture(editbox.Texture,unit.TextureProfileName)
		if(unit.Color)then
			local color=unit.Color
			editbox:SetTextColor(color.r,color.g,color.b,color.a)
			editbox.Texture:SetVertexColor(color.r,color.g,color.b,color.a)
		end
		--
		editbox:SetText(unit.Text or "")
	elseif(forcematch)then
		--force it to match one of the options
		_,unit=next(libfunc())
		--RS.SetTextFont(editbox,unit.Font,unit.FontProfileName)
		--RS.SetTexture(editbox.Texture,unit.TextureProfileName)
		if(unit.Color)then
			local color=unit.Color
			editbox:SetTextColor(color.r,color.g,color.b,color.a)
			editbox.Texture:SetVertexColor(color.r,color.g,color.b,color.a)
		end
		--
		editbox:SetText(unit.Text or "")
		editbox.Value=unit.Value
		RS.RunFunc(editbox.OnValueUpdateFunc)
	else
		--RS.SetTextFont(editbox)
		editbox.Texture:Hide()
		editbox:SetText(value or "")
	end
end
--
RS.Template.CreateDropDownEditor=function(parent,width,label,tooltip,datafunc,buttonheight)
	local width=width-20
	--main
	local editbox=RS.Template.CreateEditBox(parent,width,20)
	editbox.Label=RS.Template.CreateText(editbox,label,true)
	editbox.Label:SetPoint("BOTTOM",editbox,"TOP",0,0)
	--
	editbox.Value=""
	editbox.DataFunc=datafunc
	editbox.SetByMenu=true
	--
	local dropdownmenu_onclickfunc=function(self)
		editbox:ClearFocus()
		editbox.SetByMenu=true
		editbox.Value=self.Value
		Refresh(editbox,editbox.DataFunc)
		RS.RunFunc(editbox.OnValueUpdateFunc,editbox)
	end
	editbox:HookScript("OnCursorChanged",function(self)
		--update dropdownmenu
		if(self.FreeEdit)then
			if(self.SetByMenu)then
				self.SetByMenu=nil
			else
				local text=self:GetText()
				self.Value=RS.Template.UpdateDropDownMenuKeyWord(text) or text
				RS.RunFunc(editbox.OnValueUpdateFunc,editbox)
			end
		end
	end)
	--
	local setdropdownmenu=function()
		local dropdownmenu=RS.Template.SetDropDownMenu(editbox,width,editbox.DataFunc(),dropdownmenu_onclickfunc,parent:GetParent(),buttonheight)
		if(editbox.Revers)then
			dropdownmenu:SetPoint("BOTTOMLEFT",editbox,"TOPLEFT",0,0)
		else
			dropdownmenu:SetPoint("TOPLEFT",editbox,"BOTTOMLEFT",0,0)
		end
	end
	--
	local SetSpellPicker=function()
		if(editbox.IsSpellPicker)then
			RS.SetPage("SpellLookUp",editbox.ParentPage,editbox.Value,function(value)
				editbox.Value=value
				editbox:SetText(value)
				RS.RunFunc(editbox.OnValueUpdateFunc,editbox)
			end)
		else
			--editbox:ClearFocus()
			if(RS.Template.CheckDropDownMenu(editbox))then
				RS.Template.HideDropDownMenu()
			elseif(editbox.DataFunc)then
				setdropdownmenu()
			end
		end
	end
	--
	editbox:HookScript("OnEditFocusGained",function()
		if(editbox.DataFunc)then
			if(not RS.Template.CheckDropDownMenu(editbox))then
				setdropdownmenu()
			end
		else
			RS.Template.HideDropDownMenu()
		end
		if(not editbox.FreeEdit)then
			editbox:ClearFocus()
		end
		SetSpellPicker()
	end)
	editbox:HookScript("OnEditFocusLost",function()
		Refresh(editbox,editbox.DataFunc)
		RS.Template.HideDropDownMenu()
		SetSpellPicker()
	end)
	editbox:HookScript("OnHide",function()
		RS.Template.HideDropDownMenu()
	end)

	RS.Template.SetTooltips(tooltip or Localization["InputValue"],editbox)
	--dropdown button
	editbox.Button=RS.Template.CreateButton(editbox,20,20,"+")
	editbox.Button:SetScript("OnMouseUp",SetSpellPicker)
	editbox.Button:SetPoint("LEFT",editbox,"RIGHT",0,0)
	RS.Template.SetTooltips(Localization["ClickForMenu"],editbox.Button)
	editbox.Button:Show()
	--
	editbox.Texture=editbox:CreateTexture(nil,"BACKGROUND")
	editbox.Texture:SetPoint("TOPLEFT",editbox,"TOPLEFT")
	editbox.Texture:SetPoint("BOTTOMRIGHT",editbox,"BOTTOMRIGHT")
	--show
	editbox:Show()
	--
	return editbox
end
--set
RS.Template.SetDropDownEditor=function(editbox,value,libfunc,forcematch)
	editbox.Value=value

	if(libfunc)then
		editbox.DataFunc=libfunc
		Refresh(editbox,libfunc,forcematch)
	else
		Refresh(editbox,editbox.DataFunc,forcematch)
	end
end
--
RS.Template.DisableDropDownEditor=function(editor)
	if(not editor.DisableLiner)then
		local texture=editor:CreateTexture(nil,"OVERLAY")
		texture:SetPoint("LEFT",editor,"LEFT",0,0)
		texture:SetPoint("RIGHT",editor,"RIGHT",0,0)
		texture:SetHeight(editor:GetHeight()/5)
		texture:SetTexture("Interface\\Addons\\NPA2_Options\\texture\\Liner")
		texture:Show()
		editor.DisableLiner=texture
	else
		editor.DisableLiner:Show()
	end
	editor:SetAlpha(0.5)
	editor:EnableMouse(false)
end
--macro for enable button
RS.Template.EnableDropDownEditor=function(editor)
	if(editor.DisableLiner)then
		editor.DisableLiner:Hide()
	end
	editor:SetAlpha(1)
	editor:EnableMouse(true)
end
--
--macro for creating color mode list
RS.Template.CreateColorModeList=function(parent,width,groupname,dataselector,buttonheight)
	local datafunc=function()
		return RS.InfoLib.GetColorModeList(groupname,dataselector.Value)
	end
	return RS.Template.CreateDropDownEditor(parent,width,Localization["ColorMode"],nil,datafunc,buttonheight)
end
--macro for creating data type list
RS.Template.CreateDataTypeList=function(parent,width,groupname,buttonheight)
	local datafunc=function()
		return RS.InfoLib.GetDataType(groupname)
	end
	return RS.Template.CreateDropDownEditor(parent,width,Localization["DataType"],Tooltips["DataType"][groupname],datafunc,buttonheight)
end
--macro for creating anchor frame list
RS.Template.CreateAnchorFrameList=function(parent,width,framegroup,buttonheight)
	local datafunc=function()
		return RS.InfoLib.GetAnchorFrameList(RS.GetPage("NamePlatePreview").FrameData.ModuleMain.FrameGroup)
	end
	return RS.Template.CreateDropDownEditor(parent,width,Localization["AnchorFrame"],Tooltips["AnchorFrame"],datafunc,buttonheight)
end
